pub struct RegulatedInformation {
pub fields: Vec<RegulatedInformationField>,
}Expand description
RegulatedInformation : The regulated information collected during purchase and used to verify the order.
Fields
fields: Vec<RegulatedInformationField>A list of regulated information fields as collected from the regulatory form.
Implementations
sourceimpl RegulatedInformation
impl RegulatedInformation
sourcepub fn new(fields: Vec<RegulatedInformationField>) -> RegulatedInformation
pub fn new(fields: Vec<RegulatedInformationField>) -> RegulatedInformation
The regulated information collected during purchase and used to verify the order.